from telethon.tl.types.contacts.link import Link
from telethon.tl.types.contacts.contacts_not_modified import ContactsNotModified
from telethon.tl.types.contacts.contacts import Contacts
from telethon.tl.types.contacts.imported_contacts import ImportedContacts
from telethon.tl.types.contacts.blocked import Blocked
from telethon.tl.types.contacts.blocked_slice import BlockedSlice
from telethon.tl.types.contacts.found import Found
from telethon.tl.types.contacts.resolved_peer import ResolvedPeer
from telethon.tl.types.contacts.top_peers_not_modified import TopPeersNotModified
from telethon.tl.types.contacts.top_peers import TopPeers
