from telethon.tl.types.updates.state import State
from telethon.tl.types.updates.difference_empty import DifferenceEmpty
from telethon.tl.types.updates.difference import Difference
from telethon.tl.types.updates.difference_slice import DifferenceSlice
from telethon.tl.types.updates.channel_difference_empty import ChannelDifferenceEmpty
from telethon.tl.types.updates.channel_difference_too_long import ChannelDifferenceTooLong
from telethon.tl.types.updates.channel_difference import ChannelDifference
