from telethon.tl.mtproto_request import MTProtoRequest


class InputStickerSetID(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    inputStickerSetID#9de7a269 id:long access_hash:long = InputStickerSet"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x9de7a269

    def __init__(self, id, access_hash):
        """
        :param id: Telegram type: «long».
        :param access_hash: Telegram type: «long».
        """
        super().__init__()

        self.id = id
        self.access_hash = access_hash

    def on_send(self, writer):
        writer.write_int(InputStickerSetID.constructor_id, signed=False)
        writer.write_long(self.id)
        writer.write_long(self.access_hash)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return InputStickerSetID(None, None)

    def on_response(self, reader):
        self.id = reader.read_long()
        self.access_hash = reader.read_long()

    def __repr__(self):
        return 'inputStickerSetID#9de7a269 id:long access_hash:long = InputStickerSet'

    def __str__(self):
        return '(inputStickerSetID (ID: 0x9de7a269) = (id={}, access_hash={}))'.format(str(self.id), str(self.access_hash))
