from telethon.tl.types.messages.dialogs import Dialogs
from telethon.tl.types.messages.dialogs_slice import DialogsSlice
from telethon.tl.types.messages.messages import Messages
from telethon.tl.types.messages.messages_slice import MessagesSlice
from telethon.tl.types.messages.channel_messages import ChannelMessages
from telethon.tl.types.messages.chats import Chats
from telethon.tl.types.messages.chat_full import ChatFull
from telethon.tl.types.messages.affected_history import AffectedHistory
from telethon.tl.types.messages.dh_config_not_modified import DhConfigNotModified
from telethon.tl.types.messages.dh_config import DhConfig
from telethon.tl.types.messages.sent_encrypted_message import SentEncryptedMessage
from telethon.tl.types.messages.sent_encrypted_file import SentEncryptedFile
from telethon.tl.types.messages.stickers_not_modified import StickersNotModified
from telethon.tl.types.messages.stickers import Stickers
from telethon.tl.types.messages.all_stickers_not_modified import AllStickersNotModified
from telethon.tl.types.messages.all_stickers import AllStickers
from telethon.tl.types.messages.affected_messages import AffectedMessages
from telethon.tl.types.messages.sticker_set import StickerSet
from telethon.tl.types.messages.found_gifs import FoundGifs
from telethon.tl.types.messages.saved_gifs_not_modified import SavedGifsNotModified
from telethon.tl.types.messages.saved_gifs import SavedGifs
from telethon.tl.types.messages.bot_results import BotResults
from telethon.tl.types.messages.bot_callback_answer import BotCallbackAnswer
from telethon.tl.types.messages.message_edit_data import MessageEditData
from telethon.tl.types.messages.peer_dialogs import PeerDialogs
from telethon.tl.types.messages.featured_stickers_not_modified import FeaturedStickersNotModified
from telethon.tl.types.messages.featured_stickers import FeaturedStickers
from telethon.tl.types.messages.recent_stickers_not_modified import RecentStickersNotModified
from telethon.tl.types.messages.recent_stickers import RecentStickers
from telethon.tl.types.messages.archived_stickers import ArchivedStickers
from telethon.tl.types.messages.sticker_set_install_result_success import StickerSetInstallResultSuccess
from telethon.tl.types.messages.sticker_set_install_result_archive import StickerSetInstallResultArchive
from telethon.tl.types.messages.high_scores import HighScores
