from telethon.tl.mtproto_request import MTProtoRequest


class UpdateDraftMessage(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    updateDraftMessage#ee2bb969 peer:Peer draft:DraftMessage = Update"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xee2bb969

    def __init__(self, peer, draft):
        """
        :param peer: Telegram type: «Peer».
        :param draft: Telegram type: «DraftMessage».
        """
        super().__init__()

        self.peer = peer
        self.draft = draft

    def on_send(self, writer):
        writer.write_int(UpdateDraftMessage.constructor_id, signed=False)
        self.peer.on_send(writer)
        self.draft.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return UpdateDraftMessage(None, None)

    def on_response(self, reader):
        self.peer = reader.tgread_object()
        self.draft = reader.tgread_object()

    def __repr__(self):
        return 'updateDraftMessage#ee2bb969 peer:Peer draft:DraftMessage = Update'

    def __str__(self):
        return '(updateDraftMessage (ID: 0xee2bb969) = (peer={}, draft={}))'.format(str(self.peer), str(self.draft))
