from telethon.tl.functions.help.get_config import GetConfigRequest
from telethon.tl.functions.help.get_nearest_dc import GetNearestDcRequest
from telethon.tl.functions.help.get_app_update import GetAppUpdateRequest
from telethon.tl.functions.help.save_app_log import SaveAppLogRequest
from telethon.tl.functions.help.get_invite_text import GetInviteTextRequest
from telethon.tl.functions.help.get_support import GetSupportRequest
from telethon.tl.functions.help.get_app_changelog import GetAppChangelogRequest
from telethon.tl.functions.help.get_terms_of_service import GetTermsOfServiceRequest
