from telethon.tl.functions.contacts.get_statuses import GetStatusesRequest
from telethon.tl.functions.contacts.get_contacts import GetContactsRequest
from telethon.tl.functions.contacts.import_contacts import ImportContactsRequest
from telethon.tl.functions.contacts.delete_contact import DeleteContactRequest
from telethon.tl.functions.contacts.delete_contacts import DeleteContactsRequest
from telethon.tl.functions.contacts.block import BlockRequest
from telethon.tl.functions.contacts.unblock import UnblockRequest
from telethon.tl.functions.contacts.get_blocked import GetBlockedRequest
from telethon.tl.functions.contacts.export_card import ExportCardRequest
from telethon.tl.functions.contacts.import_card import ImportCardRequest
from telethon.tl.functions.contacts.search import SearchRequest
from telethon.tl.functions.contacts.resolve_username import ResolveUsernameRequest
from telethon.tl.functions.contacts.get_top_peers import GetTopPeersRequest
from telethon.tl.functions.contacts.reset_top_peer_rating import ResetTopPeerRatingRequest
