from telethon.tl.mtproto_request import MTProtoRequest


class UpdateUserTyping(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    updateUserTyping#5c486927 user_id:int action:SendMessageAction = Update"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x5c486927

    def __init__(self, user_id, action):
        """
        :param user_id: Telegram type: «int».
        :param action: Telegram type: «SendMessageAction».
        """
        super().__init__()

        self.user_id = user_id
        self.action = action

    def on_send(self, writer):
        writer.write_int(UpdateUserTyping.constructor_id, signed=False)
        writer.write_int(self.user_id)
        self.action.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return UpdateUserTyping(None, None)

    def on_response(self, reader):
        self.user_id = reader.read_int()
        self.action = reader.tgread_object()

    def __repr__(self):
        return 'updateUserTyping#5c486927 user_id:int action:SendMessageAction = Update'

    def __str__(self):
        return '(updateUserTyping (ID: 0x5c486927) = (user_id={}, action={}))'.format(str(self.user_id), str(self.action))
