from telethon.tl.types.storage.file_unknown import FileUnknown
from telethon.tl.types.storage.file_jpeg import FileJpeg
from telethon.tl.types.storage.file_gif import FileGif
from telethon.tl.types.storage.file_png import FilePng
from telethon.tl.types.storage.file_pdf import FilePdf
from telethon.tl.types.storage.file_mp3 import FileMp3
from telethon.tl.types.storage.file_mov import FileMov
from telethon.tl.types.storage.file_partial import FilePartial
from telethon.tl.types.storage.file_mp4 import FileMp4
from telethon.tl.types.storage.file_webp import FileWebp
