from telethon.tl.mtproto_request import MTProtoRequest


class EditChatTitleRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    messages.editChatTitle#dc452855 chat_id:int title:string = Updates"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xdc452855

    def __init__(self, chat_id, title):
        """
        :param chat_id: Telegram type: «int».
        :param title: Telegram type: «string».
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.chat_id = chat_id
        self.title = title

    def on_send(self, writer):
        writer.write_int(EditChatTitleRequest.constructor_id, signed=False)
        writer.write_int(self.chat_id)
        writer.tgwrite_string(self.title)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return EditChatTitleRequest(None, None)

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'messages.editChatTitle#dc452855 chat_id:int title:string = Updates'

    def __str__(self):
        return '(messages.editChatTitle (ID: 0xdc452855) = (chat_id={}, title={}))'.format(str(self.chat_id), str(self.title))
