from telethon.tl.functions.account.register_device import RegisterDeviceRequest
from telethon.tl.functions.account.unregister_device import UnregisterDeviceRequest
from telethon.tl.functions.account.update_notify_settings import UpdateNotifySettingsRequest
from telethon.tl.functions.account.get_notify_settings import GetNotifySettingsRequest
from telethon.tl.functions.account.reset_notify_settings import ResetNotifySettingsRequest
from telethon.tl.functions.account.update_profile import UpdateProfileRequest
from telethon.tl.functions.account.update_status import UpdateStatusRequest
from telethon.tl.functions.account.get_wall_papers import GetWallPapersRequest
from telethon.tl.functions.account.report_peer import ReportPeerRequest
from telethon.tl.functions.account.check_username import CheckUsernameRequest
from telethon.tl.functions.account.update_username import UpdateUsernameRequest
from telethon.tl.functions.account.get_privacy import GetPrivacyRequest
from telethon.tl.functions.account.set_privacy import SetPrivacyRequest
from telethon.tl.functions.account.delete_account import DeleteAccountRequest
from telethon.tl.functions.account.get_account_ttl import GetAccountTTLRequest
from telethon.tl.functions.account.set_account_ttl import SetAccountTTLRequest
from telethon.tl.functions.account.send_change_phone_code import SendChangePhoneCodeRequest
from telethon.tl.functions.account.change_phone import ChangePhoneRequest
from telethon.tl.functions.account.update_device_locked import UpdateDeviceLockedRequest
from telethon.tl.functions.account.get_authorizations import GetAuthorizationsRequest
from telethon.tl.functions.account.reset_authorization import ResetAuthorizationRequest
from telethon.tl.functions.account.get_password import GetPasswordRequest
from telethon.tl.functions.account.get_password_settings import GetPasswordSettingsRequest
from telethon.tl.functions.account.update_password_settings import UpdatePasswordSettingsRequest
from telethon.tl.functions.account.send_confirm_phone_code import SendConfirmPhoneCodeRequest
from telethon.tl.functions.account.confirm_phone import ConfirmPhoneRequest
