from telethon.tl.mtproto_request import MTProtoRequest


class UpdateNewStickerSet(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    updateNewStickerSet#688a30aa stickerset:messages.StickerSet = Update"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x688a30aa

    def __init__(self, stickerset):
        """
        :param stickerset: Telegram type: «messages.StickerSet».
        """
        super().__init__()

        self.stickerset = stickerset

    def on_send(self, writer):
        writer.write_int(UpdateNewStickerSet.constructor_id, signed=False)
        self.stickerset.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return UpdateNewStickerSet(None)

    def on_response(self, reader):
        self.stickerset = reader.tgread_object()

    def __repr__(self):
        return 'updateNewStickerSet#688a30aa stickerset:messages.StickerSet = Update'

    def __str__(self):
        return '(updateNewStickerSet (ID: 0x688a30aa) = (stickerset={}))'.format(str(self.stickerset))
