from telethon.tl.functions.upload.save_file_part import SaveFilePartRequest
from telethon.tl.functions.upload.get_file import GetFileRequest
from telethon.tl.functions.upload.save_big_file_part import SaveBigFilePartRequest
