from telethon.tl.mtproto_request import MTProtoRequest


class UpdateMessageID(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    updateMessageID#4e90bfd6 id:int random_id:long = Update"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x4e90bfd6

    def __init__(self, id, random_id):
        """
        :param id: Telegram type: «int».
        :param random_id: Telegram type: «long».
        """
        super().__init__()

        self.id = id
        self.random_id = random_id

    def on_send(self, writer):
        writer.write_int(UpdateMessageID.constructor_id, signed=False)
        writer.write_int(self.id)
        writer.write_long(self.random_id)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return UpdateMessageID(None, None)

    def on_response(self, reader):
        self.id = reader.read_int()
        self.random_id = reader.read_long()

    def __repr__(self):
        return 'updateMessageID#4e90bfd6 id:int random_id:long = Update'

    def __str__(self):
        return '(updateMessageID (ID: 0x4e90bfd6) = (id={}, random_id={}))'.format(str(self.id), str(self.random_id))
