from telethon.tl.types.res_pq import ResPQ
from telethon.tl.types.p_q_inner_data import PQInnerData
from telethon.tl.types.server_dh_params_fail import ServerDHParamsFail
from telethon.tl.types.server_dh_params_ok import ServerDHParamsOk
from telethon.tl.types.server_dh_inner_data import ServerDHInnerData
from telethon.tl.types.client_dh_inner_data import ClientDHInnerData
from telethon.tl.types.dh_gen_ok import DhGenOk
from telethon.tl.types.dh_gen_retry import DhGenRetry
from telethon.tl.types.dh_gen_fail import DhGenFail
from telethon.tl.types.msgs_ack import MsgsAck
from telethon.tl.types.bad_msg_notification import BadMsgNotification
from telethon.tl.types.bad_server_salt import BadServerSalt
from telethon.tl.types.msgs_state_req import MsgsStateReq
from telethon.tl.types.msgs_state_info import MsgsStateInfo
from telethon.tl.types.msgs_all_info import MsgsAllInfo
from telethon.tl.types.msg_detailed_info import MsgDetailedInfo
from telethon.tl.types.msg_new_detailed_info import MsgNewDetailedInfo
from telethon.tl.types.msg_resend_req import MsgResendReq
from telethon.tl.types.rpc_error import RpcError
from telethon.tl.types.rpc_answer_unknown import RpcAnswerUnknown
from telethon.tl.types.rpc_answer_dropped_running import RpcAnswerDroppedRunning
from telethon.tl.types.rpc_answer_dropped import RpcAnswerDropped
from telethon.tl.types.future_salt import FutureSalt
from telethon.tl.types.future_salts import FutureSalts
from telethon.tl.types.pong import Pong
from telethon.tl.types.destroy_session_ok import DestroySessionOk
from telethon.tl.types.destroy_session_none import DestroySessionNone
from telethon.tl.types.new_session_created import NewSessionCreated
from telethon.tl.types.http_wait import HttpWait
from telethon.tl.types.error import Error
from telethon.tl.types.null import Null
from telethon.tl.types.input_peer_empty import InputPeerEmpty
from telethon.tl.types.input_peer_self import InputPeerSelf
from telethon.tl.types.input_peer_chat import InputPeerChat
from telethon.tl.types.input_peer_user import InputPeerUser
from telethon.tl.types.input_peer_channel import InputPeerChannel
from telethon.tl.types.input_user_empty import InputUserEmpty
from telethon.tl.types.input_user_self import InputUserSelf
from telethon.tl.types.input_user import InputUser
from telethon.tl.types.input_phone_contact import InputPhoneContact
from telethon.tl.types.input_file import InputFile
from telethon.tl.types.input_file_big import InputFileBig
from telethon.tl.types.input_media_empty import InputMediaEmpty
from telethon.tl.types.input_media_uploaded_photo import InputMediaUploadedPhoto
from telethon.tl.types.input_media_photo import InputMediaPhoto
from telethon.tl.types.input_media_geo_point import InputMediaGeoPoint
from telethon.tl.types.input_media_contact import InputMediaContact
from telethon.tl.types.input_media_uploaded_document import InputMediaUploadedDocument
from telethon.tl.types.input_media_uploaded_thumb_document import InputMediaUploadedThumbDocument
from telethon.tl.types.input_media_document import InputMediaDocument
from telethon.tl.types.input_media_venue import InputMediaVenue
from telethon.tl.types.input_media_gif_external import InputMediaGifExternal
from telethon.tl.types.input_media_photo_external import InputMediaPhotoExternal
from telethon.tl.types.input_media_document_external import InputMediaDocumentExternal
from telethon.tl.types.input_media_game import InputMediaGame
from telethon.tl.types.input_chat_photo_empty import InputChatPhotoEmpty
from telethon.tl.types.input_chat_uploaded_photo import InputChatUploadedPhoto
from telethon.tl.types.input_chat_photo import InputChatPhoto
from telethon.tl.types.input_geo_point_empty import InputGeoPointEmpty
from telethon.tl.types.input_geo_point import InputGeoPoint
from telethon.tl.types.input_photo_empty import InputPhotoEmpty
from telethon.tl.types.input_photo import InputPhoto
from telethon.tl.types.input_file_location import InputFileLocation
from telethon.tl.types.input_encrypted_file_location import InputEncryptedFileLocation
from telethon.tl.types.input_document_file_location import InputDocumentFileLocation
from telethon.tl.types.input_app_event import InputAppEvent
from telethon.tl.types.peer_user import PeerUser
from telethon.tl.types.peer_chat import PeerChat
from telethon.tl.types.peer_channel import PeerChannel
from telethon.tl.types.file_location_unavailable import FileLocationUnavailable
from telethon.tl.types.file_location import FileLocation
from telethon.tl.types.user_empty import UserEmpty
from telethon.tl.types.user import User
from telethon.tl.types.user_profile_photo_empty import UserProfilePhotoEmpty
from telethon.tl.types.user_profile_photo import UserProfilePhoto
from telethon.tl.types.user_status_empty import UserStatusEmpty
from telethon.tl.types.user_status_online import UserStatusOnline
from telethon.tl.types.user_status_offline import UserStatusOffline
from telethon.tl.types.user_status_recently import UserStatusRecently
from telethon.tl.types.user_status_last_week import UserStatusLastWeek
from telethon.tl.types.user_status_last_month import UserStatusLastMonth
from telethon.tl.types.chat_empty import ChatEmpty
from telethon.tl.types.chat import Chat
from telethon.tl.types.chat_forbidden import ChatForbidden
from telethon.tl.types.channel import Channel
from telethon.tl.types.channel_forbidden import ChannelForbidden
from telethon.tl.types.chat_full import ChatFull
from telethon.tl.types.channel_full import ChannelFull
from telethon.tl.types.chat_participant import ChatParticipant
from telethon.tl.types.chat_participant_creator import ChatParticipantCreator
from telethon.tl.types.chat_participant_admin import ChatParticipantAdmin
from telethon.tl.types.chat_participants_forbidden import ChatParticipantsForbidden
from telethon.tl.types.chat_participants import ChatParticipants
from telethon.tl.types.chat_photo_empty import ChatPhotoEmpty
from telethon.tl.types.chat_photo import ChatPhoto
from telethon.tl.types.message_empty import MessageEmpty
from telethon.tl.types.message import Message
from telethon.tl.types.message_service import MessageService
from telethon.tl.types.message_media_empty import MessageMediaEmpty
from telethon.tl.types.message_media_photo import MessageMediaPhoto
from telethon.tl.types.message_media_geo import MessageMediaGeo
from telethon.tl.types.message_media_contact import MessageMediaContact
from telethon.tl.types.message_media_unsupported import MessageMediaUnsupported
from telethon.tl.types.message_media_document import MessageMediaDocument
from telethon.tl.types.message_media_web_page import MessageMediaWebPage
from telethon.tl.types.message_media_venue import MessageMediaVenue
from telethon.tl.types.message_media_game import MessageMediaGame
from telethon.tl.types.message_action_empty import MessageActionEmpty
from telethon.tl.types.message_action_chat_create import MessageActionChatCreate
from telethon.tl.types.message_action_chat_edit_title import MessageActionChatEditTitle
from telethon.tl.types.message_action_chat_edit_photo import MessageActionChatEditPhoto
from telethon.tl.types.message_action_chat_delete_photo import MessageActionChatDeletePhoto
from telethon.tl.types.message_action_chat_add_user import MessageActionChatAddUser
from telethon.tl.types.message_action_chat_delete_user import MessageActionChatDeleteUser
from telethon.tl.types.message_action_chat_joined_by_link import MessageActionChatJoinedByLink
from telethon.tl.types.message_action_channel_create import MessageActionChannelCreate
from telethon.tl.types.message_action_chat_migrate_to import MessageActionChatMigrateTo
from telethon.tl.types.message_action_channel_migrate_from import MessageActionChannelMigrateFrom
from telethon.tl.types.message_action_pin_message import MessageActionPinMessage
from telethon.tl.types.message_action_history_clear import MessageActionHistoryClear
from telethon.tl.types.message_action_game_score import MessageActionGameScore
from telethon.tl.types.dialog import Dialog
from telethon.tl.types.photo_empty import PhotoEmpty
from telethon.tl.types.photo import Photo
from telethon.tl.types.photo_size_empty import PhotoSizeEmpty
from telethon.tl.types.photo_size import PhotoSize
from telethon.tl.types.photo_cached_size import PhotoCachedSize
from telethon.tl.types.geo_point_empty import GeoPointEmpty
from telethon.tl.types.geo_point import GeoPoint
from telethon.tl.types.input_notify_peer import InputNotifyPeer
from telethon.tl.types.input_notify_users import InputNotifyUsers
from telethon.tl.types.input_notify_chats import InputNotifyChats
from telethon.tl.types.input_notify_all import InputNotifyAll
from telethon.tl.types.input_peer_notify_events_empty import InputPeerNotifyEventsEmpty
from telethon.tl.types.input_peer_notify_events_all import InputPeerNotifyEventsAll
from telethon.tl.types.input_peer_notify_settings import InputPeerNotifySettings
from telethon.tl.types.peer_notify_events_empty import PeerNotifyEventsEmpty
from telethon.tl.types.peer_notify_events_all import PeerNotifyEventsAll
from telethon.tl.types.peer_notify_settings_empty import PeerNotifySettingsEmpty
from telethon.tl.types.peer_notify_settings import PeerNotifySettings
from telethon.tl.types.peer_settings import PeerSettings
from telethon.tl.types.wall_paper import WallPaper
from telethon.tl.types.wall_paper_solid import WallPaperSolid
from telethon.tl.types.input_report_reason_spam import InputReportReasonSpam
from telethon.tl.types.input_report_reason_violence import InputReportReasonViolence
from telethon.tl.types.input_report_reason_pornography import InputReportReasonPornography
from telethon.tl.types.input_report_reason_other import InputReportReasonOther
from telethon.tl.types.user_full import UserFull
from telethon.tl.types.contact import Contact
from telethon.tl.types.imported_contact import ImportedContact
from telethon.tl.types.contact_blocked import ContactBlocked
from telethon.tl.types.contact_status import ContactStatus
from telethon.tl.types.input_messages_filter_empty import InputMessagesFilterEmpty
from telethon.tl.types.input_messages_filter_photos import InputMessagesFilterPhotos
from telethon.tl.types.input_messages_filter_video import InputMessagesFilterVideo
from telethon.tl.types.input_messages_filter_photo_video import InputMessagesFilterPhotoVideo
from telethon.tl.types.input_messages_filter_photo_video_documents import InputMessagesFilterPhotoVideoDocuments
from telethon.tl.types.input_messages_filter_document import InputMessagesFilterDocument
from telethon.tl.types.input_messages_filter_url import InputMessagesFilterUrl
from telethon.tl.types.input_messages_filter_gif import InputMessagesFilterGif
from telethon.tl.types.input_messages_filter_voice import InputMessagesFilterVoice
from telethon.tl.types.input_messages_filter_music import InputMessagesFilterMusic
from telethon.tl.types.input_messages_filter_chat_photos import InputMessagesFilterChatPhotos
from telethon.tl.types.update_new_message import UpdateNewMessage
from telethon.tl.types.update_message_id import UpdateMessageID
from telethon.tl.types.update_delete_messages import UpdateDeleteMessages
from telethon.tl.types.update_user_typing import UpdateUserTyping
from telethon.tl.types.update_chat_user_typing import UpdateChatUserTyping
from telethon.tl.types.update_chat_participants import UpdateChatParticipants
from telethon.tl.types.update_user_status import UpdateUserStatus
from telethon.tl.types.update_user_name import UpdateUserName
from telethon.tl.types.update_user_photo import UpdateUserPhoto
from telethon.tl.types.update_contact_registered import UpdateContactRegistered
from telethon.tl.types.update_contact_link import UpdateContactLink
from telethon.tl.types.update_new_authorization import UpdateNewAuthorization
from telethon.tl.types.update_new_encrypted_message import UpdateNewEncryptedMessage
from telethon.tl.types.update_encrypted_chat_typing import UpdateEncryptedChatTyping
from telethon.tl.types.update_encryption import UpdateEncryption
from telethon.tl.types.update_encrypted_messages_read import UpdateEncryptedMessagesRead
from telethon.tl.types.update_chat_participant_add import UpdateChatParticipantAdd
from telethon.tl.types.update_chat_participant_delete import UpdateChatParticipantDelete
from telethon.tl.types.update_dc_options import UpdateDcOptions
from telethon.tl.types.update_user_blocked import UpdateUserBlocked
from telethon.tl.types.update_notify_settings import UpdateNotifySettings
from telethon.tl.types.update_service_notification import UpdateServiceNotification
from telethon.tl.types.update_privacy import UpdatePrivacy
from telethon.tl.types.update_user_phone import UpdateUserPhone
from telethon.tl.types.update_read_history_inbox import UpdateReadHistoryInbox
from telethon.tl.types.update_read_history_outbox import UpdateReadHistoryOutbox
from telethon.tl.types.update_web_page import UpdateWebPage
from telethon.tl.types.update_read_messages_contents import UpdateReadMessagesContents
from telethon.tl.types.update_channel_too_long import UpdateChannelTooLong
from telethon.tl.types.update_channel import UpdateChannel
from telethon.tl.types.update_new_channel_message import UpdateNewChannelMessage
from telethon.tl.types.update_read_channel_inbox import UpdateReadChannelInbox
from telethon.tl.types.update_delete_channel_messages import UpdateDeleteChannelMessages
from telethon.tl.types.update_channel_message_views import UpdateChannelMessageViews
from telethon.tl.types.update_chat_admins import UpdateChatAdmins
from telethon.tl.types.update_chat_participant_admin import UpdateChatParticipantAdmin
from telethon.tl.types.update_new_sticker_set import UpdateNewStickerSet
from telethon.tl.types.update_sticker_sets_order import UpdateStickerSetsOrder
from telethon.tl.types.update_sticker_sets import UpdateStickerSets
from telethon.tl.types.update_saved_gifs import UpdateSavedGifs
from telethon.tl.types.update_bot_inline_query import UpdateBotInlineQuery
from telethon.tl.types.update_bot_inline_send import UpdateBotInlineSend
from telethon.tl.types.update_edit_channel_message import UpdateEditChannelMessage
from telethon.tl.types.update_channel_pinned_message import UpdateChannelPinnedMessage
from telethon.tl.types.update_bot_callback_query import UpdateBotCallbackQuery
from telethon.tl.types.update_edit_message import UpdateEditMessage
from telethon.tl.types.update_inline_bot_callback_query import UpdateInlineBotCallbackQuery
from telethon.tl.types.update_read_channel_outbox import UpdateReadChannelOutbox
from telethon.tl.types.update_draft_message import UpdateDraftMessage
from telethon.tl.types.update_read_featured_stickers import UpdateReadFeaturedStickers
from telethon.tl.types.update_recent_stickers import UpdateRecentStickers
from telethon.tl.types.update_config import UpdateConfig
from telethon.tl.types.update_pts_changed import UpdatePtsChanged
from telethon.tl.types.updates_too_long import UpdatesTooLong
from telethon.tl.types.update_short_message import UpdateShortMessage
from telethon.tl.types.update_short_chat_message import UpdateShortChatMessage
from telethon.tl.types.update_short import UpdateShort
from telethon.tl.types.updates_combined import UpdatesCombined
from telethon.tl.types.updates_tg import UpdatesTg
from telethon.tl.types.update_short_sent_message import UpdateShortSentMessage
from telethon.tl.types.dc_option import DcOption
from telethon.tl.types.config import Config
from telethon.tl.types.nearest_dc import NearestDc
from telethon.tl.types.encrypted_chat_empty import EncryptedChatEmpty
from telethon.tl.types.encrypted_chat_waiting import EncryptedChatWaiting
from telethon.tl.types.encrypted_chat_requested import EncryptedChatRequested
from telethon.tl.types.encrypted_chat import EncryptedChat
from telethon.tl.types.encrypted_chat_discarded import EncryptedChatDiscarded
from telethon.tl.types.input_encrypted_chat import InputEncryptedChat
from telethon.tl.types.encrypted_file_empty import EncryptedFileEmpty
from telethon.tl.types.encrypted_file import EncryptedFile
from telethon.tl.types.input_encrypted_file_empty import InputEncryptedFileEmpty
from telethon.tl.types.input_encrypted_file_uploaded import InputEncryptedFileUploaded
from telethon.tl.types.input_encrypted_file import InputEncryptedFile
from telethon.tl.types.input_encrypted_file_big_uploaded import InputEncryptedFileBigUploaded
from telethon.tl.types.encrypted_message import EncryptedMessage
from telethon.tl.types.encrypted_message_service import EncryptedMessageService
from telethon.tl.types.input_document_empty import InputDocumentEmpty
from telethon.tl.types.input_document import InputDocument
from telethon.tl.types.document_empty import DocumentEmpty
from telethon.tl.types.document import Document
from telethon.tl.types.notify_peer import NotifyPeer
from telethon.tl.types.notify_users import NotifyUsers
from telethon.tl.types.notify_chats import NotifyChats
from telethon.tl.types.notify_all import NotifyAll
from telethon.tl.types.send_message_typing_action import SendMessageTypingAction
from telethon.tl.types.send_message_cancel_action import SendMessageCancelAction
from telethon.tl.types.send_message_record_video_action import SendMessageRecordVideoAction
from telethon.tl.types.send_message_upload_video_action import SendMessageUploadVideoAction
from telethon.tl.types.send_message_record_audio_action import SendMessageRecordAudioAction
from telethon.tl.types.send_message_upload_audio_action import SendMessageUploadAudioAction
from telethon.tl.types.send_message_upload_photo_action import SendMessageUploadPhotoAction
from telethon.tl.types.send_message_upload_document_action import SendMessageUploadDocumentAction
from telethon.tl.types.send_message_geo_location_action import SendMessageGeoLocationAction
from telethon.tl.types.send_message_choose_contact_action import SendMessageChooseContactAction
from telethon.tl.types.send_message_game_play_action import SendMessageGamePlayAction
from telethon.tl.types.send_message_game_stop_action import SendMessageGameStopAction
from telethon.tl.types.input_privacy_key_status_timestamp import InputPrivacyKeyStatusTimestamp
from telethon.tl.types.input_privacy_key_chat_invite import InputPrivacyKeyChatInvite
from telethon.tl.types.privacy_key_status_timestamp import PrivacyKeyStatusTimestamp
from telethon.tl.types.privacy_key_chat_invite import PrivacyKeyChatInvite
from telethon.tl.types.input_privacy_value_allow_contacts import InputPrivacyValueAllowContacts
from telethon.tl.types.input_privacy_value_allow_all import InputPrivacyValueAllowAll
from telethon.tl.types.input_privacy_value_allow_users import InputPrivacyValueAllowUsers
from telethon.tl.types.input_privacy_value_disallow_contacts import InputPrivacyValueDisallowContacts
from telethon.tl.types.input_privacy_value_disallow_all import InputPrivacyValueDisallowAll
from telethon.tl.types.input_privacy_value_disallow_users import InputPrivacyValueDisallowUsers
from telethon.tl.types.privacy_value_allow_contacts import PrivacyValueAllowContacts
from telethon.tl.types.privacy_value_allow_all import PrivacyValueAllowAll
from telethon.tl.types.privacy_value_allow_users import PrivacyValueAllowUsers
from telethon.tl.types.privacy_value_disallow_contacts import PrivacyValueDisallowContacts
from telethon.tl.types.privacy_value_disallow_all import PrivacyValueDisallowAll
from telethon.tl.types.privacy_value_disallow_users import PrivacyValueDisallowUsers
from telethon.tl.types.account_days_ttl import AccountDaysTTL
from telethon.tl.types.document_attribute_image_size import DocumentAttributeImageSize
from telethon.tl.types.document_attribute_animated import DocumentAttributeAnimated
from telethon.tl.types.document_attribute_sticker import DocumentAttributeSticker
from telethon.tl.types.document_attribute_video import DocumentAttributeVideo
from telethon.tl.types.document_attribute_audio import DocumentAttributeAudio
from telethon.tl.types.document_attribute_filename import DocumentAttributeFilename
from telethon.tl.types.document_attribute_has_stickers import DocumentAttributeHasStickers
from telethon.tl.types.sticker_pack import StickerPack
from telethon.tl.types.disabled_feature import DisabledFeature
from telethon.tl.types.contact_link_unknown import ContactLinkUnknown
from telethon.tl.types.contact_link_none import ContactLinkNone
from telethon.tl.types.contact_link_has_phone import ContactLinkHasPhone
from telethon.tl.types.contact_link_contact import ContactLinkContact
from telethon.tl.types.web_page_empty import WebPageEmpty
from telethon.tl.types.web_page_pending import WebPagePending
from telethon.tl.types.web_page import WebPage
from telethon.tl.types.authorization import Authorization
from telethon.tl.types.received_notify_message import ReceivedNotifyMessage
from telethon.tl.types.chat_invite_empty import ChatInviteEmpty
from telethon.tl.types.chat_invite_exported import ChatInviteExported
from telethon.tl.types.chat_invite_already import ChatInviteAlready
from telethon.tl.types.chat_invite import ChatInvite
from telethon.tl.types.input_sticker_set_empty import InputStickerSetEmpty
from telethon.tl.types.input_sticker_set_id import InputStickerSetID
from telethon.tl.types.input_sticker_set_short_name import InputStickerSetShortName
from telethon.tl.types.sticker_set import StickerSet
from telethon.tl.types.bot_command import BotCommand
from telethon.tl.types.bot_info import BotInfo
from telethon.tl.types.keyboard_button import KeyboardButton
from telethon.tl.types.keyboard_button_url import KeyboardButtonUrl
from telethon.tl.types.keyboard_button_callback import KeyboardButtonCallback
from telethon.tl.types.keyboard_button_request_phone import KeyboardButtonRequestPhone
from telethon.tl.types.keyboard_button_request_geo_location import KeyboardButtonRequestGeoLocation
from telethon.tl.types.keyboard_button_switch_inline import KeyboardButtonSwitchInline
from telethon.tl.types.keyboard_button_game import KeyboardButtonGame
from telethon.tl.types.keyboard_button_row import KeyboardButtonRow
from telethon.tl.types.reply_keyboard_hide import ReplyKeyboardHide
from telethon.tl.types.reply_keyboard_force_reply import ReplyKeyboardForceReply
from telethon.tl.types.reply_keyboard_markup import ReplyKeyboardMarkup
from telethon.tl.types.reply_inline_markup import ReplyInlineMarkup
from telethon.tl.types.message_entity_unknown import MessageEntityUnknown
from telethon.tl.types.message_entity_mention import MessageEntityMention
from telethon.tl.types.message_entity_hashtag import MessageEntityHashtag
from telethon.tl.types.message_entity_bot_command import MessageEntityBotCommand
from telethon.tl.types.message_entity_url import MessageEntityUrl
from telethon.tl.types.message_entity_email import MessageEntityEmail
from telethon.tl.types.message_entity_bold import MessageEntityBold
from telethon.tl.types.message_entity_italic import MessageEntityItalic
from telethon.tl.types.message_entity_code import MessageEntityCode
from telethon.tl.types.message_entity_pre import MessageEntityPre
from telethon.tl.types.message_entity_text_url import MessageEntityTextUrl
from telethon.tl.types.message_entity_mention_name import MessageEntityMentionName
from telethon.tl.types.input_message_entity_mention_name import InputMessageEntityMentionName
from telethon.tl.types.input_channel_empty import InputChannelEmpty
from telethon.tl.types.input_channel import InputChannel
from telethon.tl.types.message_range import MessageRange
from telethon.tl.types.channel_messages_filter_empty import ChannelMessagesFilterEmpty
from telethon.tl.types.channel_messages_filter import ChannelMessagesFilter
from telethon.tl.types.channel_participant import ChannelParticipant
from telethon.tl.types.channel_participant_self import ChannelParticipantSelf
from telethon.tl.types.channel_participant_moderator import ChannelParticipantModerator
from telethon.tl.types.channel_participant_editor import ChannelParticipantEditor
from telethon.tl.types.channel_participant_kicked import ChannelParticipantKicked
from telethon.tl.types.channel_participant_creator import ChannelParticipantCreator
from telethon.tl.types.channel_participants_recent import ChannelParticipantsRecent
from telethon.tl.types.channel_participants_admins import ChannelParticipantsAdmins
from telethon.tl.types.channel_participants_kicked import ChannelParticipantsKicked
from telethon.tl.types.channel_participants_bots import ChannelParticipantsBots
from telethon.tl.types.channel_role_empty import ChannelRoleEmpty
from telethon.tl.types.channel_role_moderator import ChannelRoleModerator
from telethon.tl.types.channel_role_editor import ChannelRoleEditor
from telethon.tl.types.found_gif import FoundGif
from telethon.tl.types.found_gif_cached import FoundGifCached
from telethon.tl.types.input_bot_inline_message_media_auto import InputBotInlineMessageMediaAuto
from telethon.tl.types.input_bot_inline_message_text import InputBotInlineMessageText
from telethon.tl.types.input_bot_inline_message_media_geo import InputBotInlineMessageMediaGeo
from telethon.tl.types.input_bot_inline_message_media_venue import InputBotInlineMessageMediaVenue
from telethon.tl.types.input_bot_inline_message_media_contact import InputBotInlineMessageMediaContact
from telethon.tl.types.input_bot_inline_message_game import InputBotInlineMessageGame
from telethon.tl.types.input_bot_inline_result import InputBotInlineResult
from telethon.tl.types.input_bot_inline_result_photo import InputBotInlineResultPhoto
from telethon.tl.types.input_bot_inline_result_document import InputBotInlineResultDocument
from telethon.tl.types.input_bot_inline_result_game import InputBotInlineResultGame
from telethon.tl.types.bot_inline_message_media_auto import BotInlineMessageMediaAuto
from telethon.tl.types.bot_inline_message_text import BotInlineMessageText
from telethon.tl.types.bot_inline_message_media_geo import BotInlineMessageMediaGeo
from telethon.tl.types.bot_inline_message_media_venue import BotInlineMessageMediaVenue
from telethon.tl.types.bot_inline_message_media_contact import BotInlineMessageMediaContact
from telethon.tl.types.bot_inline_result import BotInlineResult
from telethon.tl.types.bot_inline_media_result import BotInlineMediaResult
from telethon.tl.types.exported_message_link import ExportedMessageLink
from telethon.tl.types.message_fwd_header import MessageFwdHeader
from telethon.tl.types.input_bot_inline_message_id import InputBotInlineMessageID
from telethon.tl.types.inline_bot_switch_pm import InlineBotSwitchPM
from telethon.tl.types.top_peer import TopPeer
from telethon.tl.types.top_peer_category_bots_pm import TopPeerCategoryBotsPM
from telethon.tl.types.top_peer_category_bots_inline import TopPeerCategoryBotsInline
from telethon.tl.types.top_peer_category_correspondents import TopPeerCategoryCorrespondents
from telethon.tl.types.top_peer_category_groups import TopPeerCategoryGroups
from telethon.tl.types.top_peer_category_channels import TopPeerCategoryChannels
from telethon.tl.types.top_peer_category_peers import TopPeerCategoryPeers
from telethon.tl.types.draft_message_empty import DraftMessageEmpty
from telethon.tl.types.draft_message import DraftMessage
from telethon.tl.types.sticker_set_covered import StickerSetCovered
from telethon.tl.types.sticker_set_multi_covered import StickerSetMultiCovered
from telethon.tl.types.mask_coords import MaskCoords
from telethon.tl.types.input_stickered_media_photo import InputStickeredMediaPhoto
from telethon.tl.types.input_stickered_media_document import InputStickeredMediaDocument
from telethon.tl.types.game import Game
from telethon.tl.types.input_game_id import InputGameID
from telethon.tl.types.input_game_short_name import InputGameShortName
from telethon.tl.types.high_score import HighScore
