from telethon.tl.functions.req_pq import ReqPqRequest
from telethon.tl.functions.req_dh_params import ReqDHParamsRequest
from telethon.tl.functions.set_client_dh_params import SetClientDHParamsRequest
from telethon.tl.functions.rpc_drop_answer import RpcDropAnswerRequest
from telethon.tl.functions.get_future_salts import GetFutureSaltsRequest
from telethon.tl.functions.ping import PingRequest
from telethon.tl.functions.ping_delay_disconnect import PingDelayDisconnectRequest
from telethon.tl.functions.destroy_session import DestroySessionRequest
from telethon.tl.functions.invoke_after_msg import InvokeAfterMsgRequest
from telethon.tl.functions.invoke_after_msgs import InvokeAfterMsgsRequest
from telethon.tl.functions.init_connection import InitConnectionRequest
from telethon.tl.functions.invoke_with_layer import InvokeWithLayerRequest
from telethon.tl.functions.invoke_without_updates import InvokeWithoutUpdatesRequest
