from telethon.tl.mtproto_request import MTProtoRequest


class ChannelRoleModerator(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    channelRoleModerator#9618d975  = ChannelParticipantRole"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x9618d975

    def __init__(self):
        super().__init__()

    def on_send(self, writer):
        writer.write_int(ChannelRoleModerator.constructor_id, signed=False)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return ChannelRoleModerator()

    def on_response(self, reader):
        pass

    def __repr__(self):
        return 'channelRoleModerator#9618d975  = ChannelParticipantRole'

    def __str__(self):
        return '(channelRoleModerator (ID: 0x9618d975) = ())'.format()
