from telethon.tl.mtproto_request import MTProtoRequest


class UninstallStickerSetRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    messages.uninstallStickerSet#f96e55de stickerset:InputStickerSet = Bool"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xf96e55de

    def __init__(self, stickerset):
        """
        :param stickerset: Telegram type: «InputStickerSet».
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.stickerset = stickerset

    def on_send(self, writer):
        writer.write_int(UninstallStickerSetRequest.constructor_id, signed=False)
        self.stickerset.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return UninstallStickerSetRequest(None)

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'messages.uninstallStickerSet#f96e55de stickerset:InputStickerSet = Bool'

    def __str__(self):
        return '(messages.uninstallStickerSet (ID: 0xf96e55de) = (stickerset={}))'.format(str(self.stickerset))
