from telethon.tl.functions.channels.read_history import ReadHistoryRequest
from telethon.tl.functions.channels.delete_messages import DeleteMessagesRequest
from telethon.tl.functions.channels.delete_user_history import DeleteUserHistoryRequest
from telethon.tl.functions.channels.report_spam import ReportSpamRequest
from telethon.tl.functions.channels.get_messages import GetMessagesRequest
from telethon.tl.functions.channels.get_participants import GetParticipantsRequest
from telethon.tl.functions.channels.get_participant import GetParticipantRequest
from telethon.tl.functions.channels.get_channels import GetChannelsRequest
from telethon.tl.functions.channels.get_full_channel import GetFullChannelRequest
from telethon.tl.functions.channels.create_channel import CreateChannelRequest
from telethon.tl.functions.channels.edit_about import EditAboutRequest
from telethon.tl.functions.channels.edit_admin import EditAdminRequest
from telethon.tl.functions.channels.edit_title import EditTitleRequest
from telethon.tl.functions.channels.edit_photo import EditPhotoRequest
from telethon.tl.functions.channels.check_username import CheckUsernameRequest
from telethon.tl.functions.channels.update_username import UpdateUsernameRequest
from telethon.tl.functions.channels.join_channel import JoinChannelRequest
from telethon.tl.functions.channels.leave_channel import LeaveChannelRequest
from telethon.tl.functions.channels.invite_to_channel import InviteToChannelRequest
from telethon.tl.functions.channels.kick_from_channel import KickFromChannelRequest
from telethon.tl.functions.channels.export_invite import ExportInviteRequest
from telethon.tl.functions.channels.delete_channel import DeleteChannelRequest
from telethon.tl.functions.channels.toggle_invites import ToggleInvitesRequest
from telethon.tl.functions.channels.export_message_link import ExportMessageLinkRequest
from telethon.tl.functions.channels.toggle_signatures import ToggleSignaturesRequest
from telethon.tl.functions.channels.update_pinned_message import UpdatePinnedMessageRequest
from telethon.tl.functions.channels.get_admined_public_channels import GetAdminedPublicChannelsRequest
