from telethon.tl.mtproto_request import MTProtoRequest


class ResetNotifySettingsRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    account.resetNotifySettings#db7e1747  = Bool"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xdb7e1747

    def __init__(self):
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

    def on_send(self, writer):
        writer.write_int(ResetNotifySettingsRequest.constructor_id, signed=False)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return ResetNotifySettingsRequest()

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'account.resetNotifySettings#db7e1747  = Bool'

    def __str__(self):
        return '(account.resetNotifySettings (ID: 0xdb7e1747) = ())'.format()
