from telethon.tl.mtproto_request import MTProtoRequest


class UpdateUserBlocked(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    updateUserBlocked#80ece81a user_id:int blocked:Bool = Update"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x80ece81a

    def __init__(self, user_id, blocked):
        """
        :param user_id: Telegram type: «int».
        :param blocked: Telegram type: «Bool».
        """
        super().__init__()

        self.user_id = user_id
        self.blocked = blocked

    def on_send(self, writer):
        writer.write_int(UpdateUserBlocked.constructor_id, signed=False)
        writer.write_int(self.user_id)
        writer.tgwrite_bool(self.blocked)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return UpdateUserBlocked(None, None)

    def on_response(self, reader):
        self.user_id = reader.read_int()
        self.blocked = reader.tgread_bool()

    def __repr__(self):
        return 'updateUserBlocked#80ece81a user_id:int blocked:Bool = Update'

    def __str__(self):
        return '(updateUserBlocked (ID: 0x80ece81a) = (user_id={}, blocked={}))'.format(str(self.user_id), str(self.blocked))
