from telethon.tl.mtproto_request import MTProtoRequest


class UpdateReadChannelOutbox(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    updateReadChannelOutbox#25d6c9c7 channel_id:int max_id:int = Update"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x25d6c9c7

    def __init__(self, channel_id, max_id):
        """
        :param channel_id: Telegram type: «int».
        :param max_id: Telegram type: «int».
        """
        super().__init__()

        self.channel_id = channel_id
        self.max_id = max_id

    def on_send(self, writer):
        writer.write_int(UpdateReadChannelOutbox.constructor_id, signed=False)
        writer.write_int(self.channel_id)
        writer.write_int(self.max_id)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return UpdateReadChannelOutbox(None, None)

    def on_response(self, reader):
        self.channel_id = reader.read_int()
        self.max_id = reader.read_int()

    def __repr__(self):
        return 'updateReadChannelOutbox#25d6c9c7 channel_id:int max_id:int = Update'

    def __str__(self):
        return '(updateReadChannelOutbox (ID: 0x25d6c9c7) = (channel_id={}, max_id={}))'.format(str(self.channel_id), str(self.max_id))
