from telethon.tl.mtproto_request import MTProtoRequest


class UpdateChatParticipants(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    updateChatParticipants#07761198 participants:ChatParticipants = Update"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x7761198

    def __init__(self, participants):
        """
        :param participants: Telegram type: «ChatParticipants».
        """
        super().__init__()

        self.participants = participants

    def on_send(self, writer):
        writer.write_int(UpdateChatParticipants.constructor_id, signed=False)
        self.participants.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return UpdateChatParticipants(None)

    def on_response(self, reader):
        self.participants = reader.tgread_object()

    def __repr__(self):
        return 'updateChatParticipants#07761198 participants:ChatParticipants = Update'

    def __str__(self):
        return '(updateChatParticipants (ID: 0x7761198) = (participants={}))'.format(str(self.participants))
