from telethon.tl.mtproto_request import MTProtoRequest


class DiscardEncryptionRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    messages.discardEncryption#edd923c5 chat_id:int = Bool"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xedd923c5

    def __init__(self, chat_id):
        """
        :param chat_id: Telegram type: «int».
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.chat_id = chat_id

    def on_send(self, writer):
        writer.write_int(DiscardEncryptionRequest.constructor_id, signed=False)
        writer.write_int(self.chat_id)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return DiscardEncryptionRequest(None)

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'messages.discardEncryption#edd923c5 chat_id:int = Bool'

    def __str__(self):
        return '(messages.discardEncryption (ID: 0xedd923c5) = (chat_id={}))'.format(str(self.chat_id))
