from telethon.tl.functions.auth.check_phone import CheckPhoneRequest
from telethon.tl.functions.auth.send_code import SendCodeRequest
from telethon.tl.functions.auth.sign_up import SignUpRequest
from telethon.tl.functions.auth.sign_in import SignInRequest
from telethon.tl.functions.auth.log_out import LogOutRequest
from telethon.tl.functions.auth.reset_authorizations import ResetAuthorizationsRequest
from telethon.tl.functions.auth.send_invites import SendInvitesRequest
from telethon.tl.functions.auth.export_authorization import ExportAuthorizationRequest
from telethon.tl.functions.auth.import_authorization import ImportAuthorizationRequest
from telethon.tl.functions.auth.bind_temp_auth_key import BindTempAuthKeyRequest
from telethon.tl.functions.auth.import_bot_authorization import ImportBotAuthorizationRequest
from telethon.tl.functions.auth.check_password import CheckPasswordRequest
from telethon.tl.functions.auth.request_password_recovery import RequestPasswordRecoveryRequest
from telethon.tl.functions.auth.recover_password import RecoverPasswordRequest
from telethon.tl.functions.auth.resend_code import ResendCodeRequest
from telethon.tl.functions.auth.cancel_code import CancelCodeRequest
from telethon.tl.functions.auth.drop_temp_auth_keys import DropTempAuthKeysRequest
