from telethon.tl.mtproto_request import MTProtoRequest


class InputStickeredMediaDocument(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    inputStickeredMediaDocument#0438865b id:InputDocument = InputStickeredMedia"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x438865b

    def __init__(self, id):
        """
        :param id: Telegram type: «InputDocument».
        """
        super().__init__()

        self.id = id

    def on_send(self, writer):
        writer.write_int(InputStickeredMediaDocument.constructor_id, signed=False)
        self.id.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return InputStickeredMediaDocument(None)

    def on_response(self, reader):
        self.id = reader.tgread_object()

    def __repr__(self):
        return 'inputStickeredMediaDocument#0438865b id:InputDocument = InputStickeredMedia'

    def __str__(self):
        return '(inputStickeredMediaDocument (ID: 0x438865b) = (id={}))'.format(str(self.id))
